#### Shapiro tests ####

# Type
Type_shapiro = myDatalong %>%
  group_by(Type) %>%
  do(tidy(shapiro.test(.$Count)))

# Landskap
Landskap_shapiro = myDatalong %>%
  group_by(Landskap) %>%
  do(tidy(shapiro.test(.$Count)))

# Type x Landskap
TypeLandskap_shapiro = myDatalong %>%
  group_by(TypeLandskap) %>%
  do(tidy(shapiro.test(.$Count)))

#### Density plots ####
# Density plot count x type
ggplot(myDatalong, aes(x=Count, fill=Type)) +
  geom_density(alpha=0.5) +
  facet_wrap(~Type) +
  theme_minimal() +
  labs(title="Tetthets plot for Elv og Land", x="Antall", y="Tetthet") +
  geom_text(data = Type_shapiro, aes(x = 20, y = 0.08, label = paste("Shapiro value:", round(p.value, 6))), inherit.aes = FALSE)

# Density plot count x landscape
ggplot(myDatalong, aes(x=Count, fill=Landskap)) +
  geom_density(alpha=0.5) +
  facet_wrap(~Landskap) +
  theme_minimal() +
  labs(title="Tetthets plot for Jordbruk og Skog", x="Antall", y="Tetthet") +
  geom_text(data = Landskap_shapiro, aes(x = 20, y = 0.20, label = paste("Shapiro value:", round(p.value, 6))), inherit.aes = FALSE)


# Plot the density by the interaction
ggplot(myDatalong, aes(x=Count, fill=TypeLandskap)) +
  geom_density(alpha=0.5) +
  facet_wrap(~TypeLandskap) +
  theme_minimal() +
  labs(title="Tetthets Plot for Elv & Land mot Skog & Jordbruk", x="Antall", y="Tetthet") +
  geom_text(data = TypeLandskap_shapiro, aes(x = 20, y = 0.25, label = paste("Shapiro value:", round(p.value, 6))), inherit.aes = FALSE)


# qqnorm
ggplot(myDatalong, aes(sample=Count)) +
  facet_wrap(~Type) +
  stat_qq() +
  stat_qq_line() +
  theme_minimal() +
  labs(title="Q-Q Plot by Type", x="Theoretical Quantiles", y="Sample Quantiles")

# qqnorm
ggplot(myDatalong, aes(sample=Count)) +
  facet_wrap(~Landskap) +
  stat_qq() +
  stat_qq_line() +
  theme_minimal() +
  labs(title="Q-Q Plot by Landscape", x="Theoretical Quantiles", y="Sample Quantiles")

# qqnorm 
ggplot(myDatalong, aes(sample=Count)) +
  facet_wrap(~TypeLandskap) +
  stat_qq() +
  stat_qq_line() +
  theme_minimal() +
  labs(title="Q-Q Plot by Type and Landscape Interaction", x="Theoretical Quantiles", y="Sample Quantiles")


# Calculate summary statistics for each Type
type_stats <- myDatalong %>%
  group_by(Type) %>%
  summarise(
    Mean = mean(Count),
    Median = median(Count),
    Mode = as.numeric(names(which.max(table(Count))))
  )

# Calculate summary statistics for each Landskap
landscape_stats <- myDatalong %>%
  group_by(Landskap) %>%
  summarise(
    Mean = mean(Count),
    Median = median(Count),
    Mode = as.numeric(names(which.max(table(Count))))
  )

# Calculate summary statistics for each TypeLandskap
type_landscape_stats <- myDatalong %>%
  group_by(TypeLandskap) %>%
  summarise(
    Mean = mean(Count),
    Median = median(Count),
    Mode = as.numeric(names(which.max(table(Count))))
  )


colnames(type_stats)[1] <- "Gruppe"
colnames(landscape_stats)[1] <- "Gruppe"
colnames(type_landscape_stats)[1] <- "Gruppe"
colnames(Type_shapiro)[1] = "Gruppe"
colnames(Landskap_shapiro)[1] = "Gruppe"
colnames(TypeLandskap_shapiro)[1] = "Gruppe"
# Combine all statistics
# Now combine the data frames
all_stats <- rbind(type_stats, landscape_stats, type_landscape_stats)
all_shaprio = rbind(Type_shapiro, Landskap_shapiro, TypeLandskap_shapiro)
print(all_stats)
print(all_shaprio)
all_stats_shaprio = merge(all_stats, all_shaprio, by = "Gruppe")
all_stats_shaprio =all_stats_shaprio[, -which(names(all_stats_shaprio) == "statistic")]
all_stats_shaprio =all_stats_shaprio[, -which(names(all_stats_shaprio) == "method")]
colnames(all_stats_shaprio)[2] = "G.snitt"
colnames(all_stats_shaprio)[3] = "Median"
colnames(all_stats_shaprio)[4] = "Modus"
colnames(all_stats_shaprio)[5] = "P-verdi"

print(all_stats_shaprio)
# Plot the summary statistics
ggplot(all_stats, aes(x = Category, y = Category)) +
  geom_tile(fill = "white", color = "black") +
  geom_text(aes(label = paste("Mean:", round(Mean, 2), "\nMedian:", round(Median, 2), "\nMode:", round(Mode, 2))), hjust = 0.5, vjust = 0.5) +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  labs(x = "Category", y = "Statistic", title = "Summary Statistics for Each Category")

write.csv(all_stats_shaprio, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/central tendency & shapiro.csv", row.names=FALSE)
write.csv(myDatalong, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/mydatalong.csv", row.names=FALSE)

# Based on all testing not normally distributed.  

# Basic density plot for mm, colored by Landskap
ggplot(mm, aes(x=mm, fill=Landskap)) +
  geom_density(alpha=0.5) +
  facet_wrap(~ Landskap, scales = "free_y") +
  theme_minimal() +
  labs(title="Density of mm by Landskap", x="mm", y="Density")

# Density plot for mm, colored by Type
ggplot(mm, aes(x=mm, fill=Type)) +
  geom_density(alpha=0.5) +
  facet_wrap(~ Type, scales = "free_y") +
  theme_minimal() +
  labs(title="Density of mm by Type", x="mm", y="Density")

# Density plot for mm, colored by Combined
ggplot(mm, aes(x=mm, fill=Combined)) +
  geom_density(alpha=0.5) +
  facet_wrap(~ Combined, scales = "free_y") +
  theme_minimal() +
  labs(title="Density of mm by Combined", x="mm", y="Density")
summary(mm)

# Calculate summary statistics for each Type
type_stats_mm <- mm %>%
  group_by(Type) %>%
  summarise(
    Mean = mean(mm),
    Median = median(mm),
    Mode = as.numeric(names(which.max(table(mm))))
  )

# Calculate summary statistics for each Landskap
landscape_stats_mm <- mm %>%
  group_by(Landskap) %>%
  summarise(
    Mean = mean(mm),
    Median = median(mm),
    Mode = as.numeric(names(which.max(table(mm))))
  )

# Calculate summary statistics for each TypeLandskap
type_landscape_stats_mm <- mm %>%
  group_by(Combined) %>%
  summarise(
    Mean = mean(mm),
    Median = median(mm),
    Mode = as.numeric(names(which.max(table(mm))))
  )


colnames(type_stats_mm)[1] <- "Category"
colnames(landscape_stats_mm)[1] <- "Category"
colnames(type_landscape_stats_mm)[1] <- "Category"

# Combine all statistics
# Now combine the data frames
all_stats_mm <- rbind(type_stats_mm, landscape_stats_mm, type_landscape_stats_mm)
print(all_stats_mm)
write.csv(all_stats_mm, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/central tendency.csv", row.names=FALSE)

create_qq_plots <- function(df) {
  # Get unique categories in the "Type" column
  categories <- unique(df$Type)
  
  # Initialize an empty list to store the plots
  plots <- list()
  
  # Loop through each category
  for (category in categories) {
    # Filter the dataframe by the current category
    df_filtered <- df %>% filter(Type == category)
    
    # Create a QQ plot for the "Count" values within the current category
    plot <- ggplot(df_filtered, aes(sample = Count)) +
      stat_qq() +
      stat_qq_line() +
      ggtitle(paste("QQ Plot for Category", category))
    
    # Add the plot to the list
    plots[[category]] <- plot
  }
  
  return(plots)
}

# Assuming your dataframe is named 'myDatalong'
qq_plots <- create_qq_plots(myDatalong)

# Display all QQ plots
for (plot in qq_plots) {
  print(plot)
}
