# Normalfordeling størrelse

# Density plot for mm, colored by Type
stats_Type <- mm %>%
  group_by(Type) %>%
  summarise(mean = mean(mm, na.rm = TRUE),
            median = median(mm, na.rm = TRUE),
            mode = Mode(mm),
            p_value = shapiro.test(mm)$p.value)

Dens_Type <- ggplot(mm, aes(x=mm, fill=Type)) +
  geom_density(alpha=0.5) +
  facet_wrap(~ Type, scales = "free_y") +
  theme_minimal() +
  labs(title=paste("Tetthets plot for Hovedgrupper"), x="(mm)", y="Tetthet") +
  geom_text(data = stats_Type, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
print(Dens_Type)


# Basic density plot for mm, colored by Landskap
stats_Landskap <- mm %>%
  group_by(Landskap) %>%
  summarise(mean = mean(mm, na.rm = TRUE),
            median = median(mm, na.rm = TRUE),
            mode = Mode(mm),
            p_value = shapiro.test(mm)$p.value)

Dens_Landskap <- ggplot(mm, aes(x=mm, fill=Landskap)) +
  geom_density(alpha=0.5) +
  facet_wrap(~ Landskap, scales = "free_y") +
  theme_minimal() +
  labs(title=paste("Tetthets plot for Undergrupper"), x="(mm)", y="Tetthet") +
  geom_text(data = stats_Landskap, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
print(Dens_Landskap)


# Density plot for mm, colored by Combined
stats_blanding <- mm %>%
  group_by(Combined) %>%
  summarise(mean = mean(mm, na.rm = TRUE),
            median = median(mm, na.rm = TRUE),
            mode = Mode(mm),
            p_value = shapiro.test(mm)$p.value)

Dens_Blanding <- ggplot(mm, aes(x=mm, fill=Combined)) +
  geom_density(alpha=0.5) +
  facet_wrap(~ Combined, scales = "free_y") +
  theme_minimal() +
  labs(title=paste("Tetthets plot for Blandingsgrupper"), x="(mm)", y="Tetthet") +
  geom_text(data = stats_blanding, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
print(Dens_Blanding)


# For Each location
# diff by river or land
mm <- mm %>%
  mutate(Prefix = ifelse(str_detect(L, "^E"), "E", "L"))


# Filter the data frame to include only variables that start with "E"
mm_filtered_E <- mm %>%
  filter(str_detect(L, "^E"))

# Perform the Shapiro-Wilk test on each subset
shapiro_results_E <- mm_filtered_E %>%
  group_by(L) %>%
  summarise(p_value = shapiro.test(mm)$p.value)

# Filter the data frame to include only variables that start with "L"
mm_filtered_L <- mm %>%
  filter(str_detect(L, "^L"))

# Perform the Shapiro-Wilk test on each subset
shapiro_results_L <- mm_filtered_L %>%
  group_by(L) %>%
  summarise(p_value = shapiro.test(mm)$p.value)

#### Sum stat type, landskap, mix ####
# Calculate summary statistics for each Type

type_stats_mm <- mm %>%
  group_by(Type) %>%
  summarise(
    Mean = mean(mm),
    Median = median(mm),
    Mode = as.numeric(names(which.max(table(mm)))),
    Shapiro = shapiro.test(mm)$p.value
  )


# Calculate summary statistics for each Landskap
landscape_stats_mm <- mm %>%
  group_by(Landskap) %>%
  summarise(
    Mean = mean(mm),
    Median = median(mm),
    Mode = as.numeric(names(which.max(table(mm)))),
    Shapiro = shapiro.test(mm)$p.value
  )


# Calculate summary statistics for each TypeLandskap
type_landscape_stats_mm <- mm %>%
  group_by(Combined) %>%
  summarise(
    Mean = mean(mm),
    Median = median(mm),
    Mode = as.numeric(names(which.max(table(mm)))),
    Shapiro = shapiro.test(mm)$p.value
  )



colnames(type_stats_mm)[1] <- "Category"
colnames(landscape_stats_mm)[1] <- "Category"
colnames(type_landscape_stats_mm)[1] <- "Category"

# Combine all statistics
# Now combine the data frames
all_stats_mm <- rbind(type_stats_mm, landscape_stats_mm, type_landscape_stats_mm)
print(all_stats_mm)
write.csv(all_stats_mm, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/mm_ct_shap.csv", row.names=FALSE)




#### Mode function ####
Mode <- function(x) {
  ux <- unique(x)
  ux[which.max(tabulate(match(x, ux)))]
}

#### Steder ####
# Filter the data frame to include only variables that start with "E"
mm_filtered_E <- mm %>%
  filter(str_detect(L, "^E"))

# Calculate mean, median, and mode for each group, ensuring mode is numeric
summary_stats_E <- mm_filtered_E %>%
  group_by(L) %>%
  summarise(mean = mean(mm, na.rm = TRUE),
            median = median(mm, na.rm = TRUE),
            mode = as.numeric(Mode(mm))) # Convert mode to numeric

# Perform the Shapiro-Wilk test on each subset
shapiro_results_E <- mm_filtered_E %>%
  group_by(L) %>%
  summarise(p_value = shapiro.test(mm)$p.value)

summary_stats_E <- summary_stats_E %>%
  left_join(shapiro_results_E, by = "L")


# Filter the data frame to include only variables that start with "L"
mm_filtered_L <- mm %>%
  filter(str_detect(L, "^L"))

# Calculate mean, median, and mode for each group
summary_stats_L <- mm_filtered_L %>%
  group_by(L) %>%
  summarise(mean = mean(mm, na.rm = TRUE),
            median = median(mm, na.rm = TRUE),
            mode = as.numeric(Mode(mm))) # Convert mode to numeric

# Perform the Shapiro-Wilk test on each subset
shapiro_results_L <- mm_filtered_L %>%
  group_by(L) %>%
  summarise(p_value = shapiro.test(mm)$p.value)

summary_stats_L <- summary_stats_L %>%
  left_join(shapiro_results_L, by = "L")
write.csv(summary_stats_E, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/sum_E_mm_stats.csv", row.names=FALSE)
write.csv(summary_stats_L, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/sum_L_mm_stats.csv", row.names=FALSE)

#### E1 to E6 plots ####
# Combine all specified "L" values into a single vector, River_Loc_7_9, River_Loc_10_12, River_Loc_13
E1_to_E6 <- c("E1", "E2", "E3", "E4", "E5", "E6")

# Initialize an empty list to store the plots
plots_E1_E6 <- list()

# Loop over each group of "L" values and create a plot for each
for (i in 1:length(E1_to_E6)) {
  L_value <- E1_to_E6[i]
  
  # Filter the data for the current "L" value
  mm_filtered_E_current <- mm_filtered_E %>%
    filter(L == L_value)
  
  # Assuming summary_stats_E and shapiro_results_E are already defined and filtered similarly
  summary_stats_E_current <- summary_stats_E %>%
    filter(L == L_value)
  
  shapiro_results_E_current <- shapiro_results_E %>%
    filter(L == L_value)
  
  # Create a new plot for the current "L" value
  p <- ggplot(mm_filtered_E_current, aes(x=mm, fill=L)) +
    geom_density(alpha=0.5) +
    theme_minimal() +
    labs(title=paste("Tetthets plot for mm i", L_value), x="(mm)", y="Tetthet") +
    geom_text(data = summary_stats_E_current, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
  
  # Add the plot to the list
  plots_E1_E6[[i]] <- p
}

# Arrange the plots in a 3x2 grid
do.call(grid.arrange, c(plots_E1_E6, ncol = 2))


#### E7 to E9 plots ####
# Combine all specified "L" values into a single vector
# Define the groups of "L" values
E7_to_E12 <- c("E7", "E8", "E9", "E10", "E11", "E12")

# Initialize an empty list to store the plots
plots_E7_E12 <- list()

# Loop over each group of "L" values and create a plot for each
for (i in 1:length(E7_to_E12)) {
  L_value <- E7_to_E12[i]
  
  # Filter the data for the current "L" value
  mm_filtered_E_current2 <- mm_filtered_E %>%
    filter(L == L_value)
  
  # Assuming summary_stats_E and shapiro_results_E are already defined and filtered similarly
  summary_stats_E_current2 <- summary_stats_E %>%
    filter(L == L_value)
  
  shapiro_results_E_current2 <- shapiro_results_E %>%
    filter(L == L_value)
  
  # Create a new plot for the current "L" value
  p <- ggplot(mm_filtered_E_current2, aes(x=mm, fill=L)) +
    geom_density(alpha=0.5) +
    theme_minimal() +
    labs(title=paste("Tetthets plot for mm i", L_value), x="(mm)", y="Tetthet") +
    geom_text(data = summary_stats_E_current2, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
  
  # Add the plot to the list
  plots_E7_E12[[i]] <- p
}

# Arrange the plots in a 3x2 grid
do.call(grid.arrange, c(plots_E7_E12, ncol = 2))

#### E13 ####

# Filter the data for "E13"
mm_filtered_E_E13 <- mm_filtered_E %>%
  filter(L == "E13")

# Assuming summary_stats_E and shapiro_results_E are already defined and filtered similarly
summary_stats_E_E13 <- summary_stats_E %>%
  filter(L == "E13")

shapiro_results_E_E13 <- shapiro_results_E %>%
  filter(L == "E13")

# Create a density plot for "E13"
p_E13 <- ggplot(mm_filtered_E_E13, aes(x=mm, fill=L)) +
  geom_density(alpha=0.5) +
  theme_minimal() +
  labs(title="Tetthets plot for mm i E13", x="(mm)", y="Tetthet") +
  geom_text(data = summary_stats_E_E13, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)

# Display the plot
print(p_E13)


#### L1 to L6 ####
# Combine all specified "L" values into a single vector, River_Loc_7_9, River_Loc_10_12, River_Loc_13
L1_to_L6 <- c("L1", "L2", "L3", "L4", "L5", "L6")

# Initialize an empty list to store the plots
plots_L1_L6 <- list()

# Loop over each group of "L" values and create a plot for each
for (i in 1:length(L1_to_L6)) {
  L_value <- L1_to_L6[i]
  
  # Filter the data for the current "L" value
  mm_filtered_L_current <- mm_filtered_L %>%
    filter(L == L_value)
  
  # Assuming summary_stats_E and shapiro_results_E are already defined and filtered similarly
  summary_stats_L_current <- summary_stats_L %>%
    filter(L == L_value)
  
  shapiro_results_L_current <- shapiro_results_L %>%
    filter(L == L_value)
  
  # Create a new plot for the current "L" value
  p <- ggplot(mm_filtered_L_current, aes(x=mm, fill=L)) +
    geom_density(alpha=0.5) +
    theme_minimal() +
    labs(title=paste("Tetthets plot for mm i", L_value), x="(mm)", y="Tetthet") +
    geom_text(data = summary_stats_L_current, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
  
  # Add the plot to the list
  plots_L1_L6[[i]] <- p
}

# Arrange the plots in a 3x2 grid
do.call(grid.arrange, c(plots_L1_L6, ncol = 2))


#### L7 to L12 ####
L7_to_L12 <- c("L7", "L8", "L9", "L10", "L11", "L12")

# Initialize an empty list to store the plots
plots_L7_L12 <- list()

# Loop over each group of "L" values and create a plot for each
for (i in 1:length(L7_to_L12)) {
  L_value <- L7_to_L12[i]
  
  # Filter the data for the current "L" value
  mm_filtered_L_current <- mm_filtered_L %>%
    filter(L == L_value)
  
  # Assuming summary_stats_E and shapiro_results_E are already defined and filtered similarly
  summary_stats_L_current <- summary_stats_L %>%
    filter(L == L_value)
  
  shapiro_results_L_current <- shapiro_results_L %>%
    filter(L == L_value)
  
  # Create a new plot for the current "L" value
  p <- ggplot(mm_filtered_L_current, aes(x=mm, fill=L)) +
    geom_density(alpha=0.5) +
    theme_minimal() +
    labs(title=paste("Tetthets plot for mm i", L_value), x="(mm)", y="Tetthet") +
    geom_text(data = summary_stats_L_current, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)
  
  # Add the plot to the list
  plots_L7_L12[[i]] <- p
}

# Arrange the plots in a 3x2 grid
do.call(grid.arrange, c(plots_L7_L12, ncol = 2))


#### L13 ####
# Filter the data for "L13"
mm_filtered_L_L13 <- mm_filtered_L %>%
  filter(L == "L13")

# Assuming summary_stats_E and shapiro_results_E are already defined and filtered similarly
summary_stats_L_L13 <- summary_stats_L %>%
  filter(L == "L13")

shapiro_results_L_L13 <- shapiro_results_L %>%
  filter(L == "L13")

# Create a density plot for "L13"
p_L13 <- ggplot(mm_filtered_L_L13, aes(x=mm, fill=L)) +
  geom_density(alpha=0.5) +
  theme_minimal() +
  labs(title="Tetthets plot for mm i L13", x="(mm)", y="Tetthet") +
  geom_text(data = summary_stats_L_L13, aes(x = Inf, y = Inf, label = paste("G.snitt =", round(mean, 2), "\nMedian =", round(median, 2), "\nModus =", round(mode, 2), "\nP-Verdi =", round(p_value, 5))), vjust = 1.5, hjust = 2)

# Display the plot
print(p_L13)

  E3 <- mm_filtered_E %>%
  filter(L == "E3")
E5 <- mm_filtered_E %>%
  filter(L == "E5")
par(mfrow = 1:2)
qqPlot(E3$mm, main = "E3 QQplot")
qqPlot(E5$mm, main = "E5 QQplot")
L4 = mm_filtered_L %>%
  filter(L == "L4")
L6 = mm_filtered_L %>%
  filter(L == "L6")
L13 = mm_filtered_L %>%
  filter(L == "L13")
qqPlot(L4$mm, main = "L4 QQplot")
qqPlot(L6$mm, main = "L6 QQplot")
qqPlot(L13$mm, main = "L13 QQplot")

create_qq_plots <- function(df) {
  # Get unique categories in the "L" column
  categories <- unique(mm$L)
  
  # Initialize an empty list to store the plots
  plots <- list()
  
  # Loop through each category
  for (category in categories) {
    # Filter the dataframe by the current category
    df_filtered <- df %>% filter(L == category)
    
    # Create a QQ plot for the "mm" values within the current category
    plot <- ggplot(df_filtered, aes(sample = mm)) +
      stat_qq() +
      stat_qq_line() +
      ggtitle(paste("QQ Plot for Category", category))
    
    # Add the plot to the list
    plots[[category]] <- plot
  }
  
  return(plots)
}

# Call the function with your dataframe
qq_plots <- create_qq_plots(mm)
# Display all QQ plots
for (plot in qq_plots) {
  print(plot)
}

create_qq_plots <- function(df) {
  # Get unique categories in the "L" column
  categories <- unique(mm$L)
  
  # Initialize an empty list to store the plots
  plots <- list()
  
  # Loop through each category
  for (category in categories) {
    # Filter the dataframe by the current category
    df_filtered <- df %>% filter(E == category)
    
    # Create a QQ plot for the "mm" values within the current category
    plot <- ggplot(df_filtered, aes(sample = mm)) +
      stat_qq() +
      stat_qq_line() +
      ggtitle(paste("QQ Plot for Category", category))
    
    # Add the plot to the list
    plots[[category]] <- plot
  }
  
  return(plots)
}

# Call the function with your dataframe
qq_plots <- create_qq_plots(mm)
# Display all QQ plots
for (plot in qq_plots) {
  print(plot)
}
