# Density plots with shapiro value

# River and Land count data
RL_Data <- data.frame(
  value = c(Count_R, Count_L),
  Type = factor(rep(c("River", "Land"), c(length(Count_R), length(Count_L))))
)
# Define p-values for shapiro test
shapiro_test_river <- shapiro.test(Count_R)
shapiro_test_land <- shapiro.test(Count_L)
Alpha = 0.05
# Plot the combined density of the particle count
p = ggplot(RL_Data, aes(x = value, fill = Type)) +
  geom_density(alpha = 0.5) +
  scale_fill_manual(values = c("River" = "blue", "Land" = "brown")) +
  labs(x = "Count", y = "Density", title = "Density plot of River and Land") +
  theme_minimal()

p + annotate("text", x = 30, y = 0.070, label = paste("Shapiro p-value =", round(shapiro_test_river$p.value, 5), "\nAlpha = 0.05"), color = "blue") +
  annotate("text", x = 30, y = 0.060, label = paste("Shapiro p-value =", round(shapiro_test_land$p.value, 5), "\nAlpha = 0.05"), color = "brown")

# River and land area (mm) data
RL_area = data.frame(
  value = c(River_area, Land_area),
  Type = factor(rep(c("River", "Land"), c(length(River_area), length(Land_area))))
)
# Define shapiro test for Size of particles
shapiro_test_land_mm = shapiro.test(Land_area)
shapiro_test_river_mm = shapiro.test(River_area)

#### Plot the combined density size of particles ####
O = ggplot(RL_area, aes(x = value, fill = Type)) +
  geom_density(alpha = 0.5) +
  scale_fill_manual(values = c("River" = "blue", "Land" = "brown")) +
  labs(x = "Count", y = "Density", title = "Density plot of size River and Land") +
  theme_minimal()

O + annotate("text", x = 25, y = 0.070, label = paste("Shapiro p-value =", round(shapiro_test_river_mm$p.value, 5), "\nAlpha = 0.05"), color = "blue") +
  annotate("text", x = 25, y = 0.060, label = paste("Shapiro p-value =", round(shapiro_test_land_mm$p.value, 5), "\nAlpha = 0.05"), color = "brown")


#### qq-plots ####
#         Count
par(mfrow = c(2,2))
qqnorm(Count_R, main = "River count")
qqline(Count_R)
qqnorm(Count_L, main = "Land count")
qqline(Count_L)
#         Area (mm)
qqnorm(River_area, main = "River area (mm)")
qqline(River_area)
qqnorm(Land_area, main = "Land area (mm)")
qqline(Land_area)




#### Box plot of land micro plastic ####
ggplot(myData, aes(x = Landscape, y = Land, fill = Landscape)) +
  geom_boxplot(aes(group = Landscape)) +
  labs(x = "Landscape Type", y = "Count of Land Microplastics", title = "Effect of Landscape on river Microplastic Counts") +
  theme_minimal()


#### Box plot River micro plastic ####

ggplot(myData, aes(x = Landscape, y = River, fill = Landscape)) +
  geom_boxplot(aes(group = Landscape)) +
  labs(x = "Landscape Type", y = "Count of River Microplastics", title = "Effect of Landscape on river Microplastic Counts") +
  theme_minimal()


#### Density plot of mp count by landscape grouped by land & river ####
par(mfrow = c(1, 2))
ggplot(myDataLong, aes(x = Count, fill = Landscape)) +
geom_density(alpha = 0.5) +
facet_wrap(~Type, scales = "free_x") +
labs(x = "Count of Microplastics", y = "Density", title = "Density of Microplastic Counts by Landscape") +
theme_minimal() +
  scale_fill_manual(values = c("Forest" = "darkgreen", "Farmland" = "yellow"))

#### Density plot of the size of particles by landscape grouped by land & river ####
ggplot(myDataLong, aes(x = mm, fill = Landscape)) +
  geom_density(alpha = 0.5) +
  facet_wrap(~Measurement, scales = "free_x") +
  labs(x = "size of Microplastics", y = "Density", title = "Density of Microplastic size by Landscape") +
  theme_minimal() +
  scale_fill_manual(values = c("Forest" = "darkgreen", "Farmland" = "blue"))
####  ####
# Fit a linear regression model for River

river_model <- lm(River ~ LA_mm + RA_mm + Dist_B + Landscape, data = myData)
summary(river_model)

land_model <- lm(Land ~ LA_mm + RA_mm + Dist_B + Landscape, data = myData)
summary(land_model)

# Check residuals
plot(river_model, which = 1)
plot(land_model, which = 1)

# Check for normality of residuals
shapiro.test(residuals(river_model))
shapiro.test(residuals(land_model))

# random forest
# Land count
land_forest <- randomForest(Land ~ LA_mm + RA_mm + Dist_B + Landscape, data = myData)
summary(land_forest)
# Get variable importance
importance(land_forest)
varImpPlot(land_forest)
#River count
River_forest <- randomForest(River ~ LA_mm + RA_mm + Dist_B + Landscape, data = myData)
summary(River_forest)
# Get variable importance
importance(River_forest)
varImpPlot(River_forest)

Kruskal_wallis = kruskal.test(Count ~ Landscape, data = myDataLong)
# Create the boxplot
p <- ggplot(myDataLong, aes(x = Landscape, y = Count)) +
geom_boxplot() +
labs(title = "Kruskal-Wallis Test Results")
# Add the Kruskal-Wallis test results as text annotations
p + annotate("text", x = 1, y = max(myDataLong$Count),
label = paste("Kruskal-Wallis =", round(Kruskal_wallis$p.value, 5), "\nalpha = 0.05"),
hjust = 0, vjust = 1.5, size = 4)


