# import files and code for analysis

Final_Count <- read_excel("C:/Users/Fredr/OneDrive - USN/Master oppgave/Filter bilder/Stitcha bilder/20x/Pyton kode count png/Excel_Count/Version_1/Final_Count.xlsx",
                          sheet = "Data_1")

Final_Count_long <- read_excel("C:/Users/Fredr/OneDrive - USN/Master oppgave/Filter bilder/Stitcha bilder/20x/Pyton kode count png/Excel_Count/Version_1/Final_Count.xlsx",
                          sheet = "Data_2")

mm <- read_excel("C:/Users/Fredr/OneDrive - USN/Master oppgave/Filter bilder/Stitcha bilder/20x/Pyton kode count png/Excel_Count/Version_1/Final_Count.xlsx",
                               sheet = "mm")


myData = Final_Count
myDatalong = Final_Count_long
# Create a new variable for the interaction of Type and Landscape
myDatalong$TypeLandskap <- interaction(myDatalong$Type, myDatalong$Landskap)
myDatalong <- myDatalong %>%
  mutate(Dis_Group = cut(Dis, breaks = quantile(Dis, probs = seq(0, 1, by = 0.25)), 
                         labels = c("Short", "Medium", "Far", "Extra Far"), 
                         include.lowest = TRUE))
# summary stat
summary_stats <- summary(myDatalong$Count)
# breaks based on summary statistics
breaks <- c(summary_stats["Min."], summary_stats["1st Qu."], summary_stats["Median"], summary_stats["3rd Qu."], summary_stats["Max."])
# Use cut to create bins
myDatalong <- myDatalong %>%
mutate(Count_Cat = cut(Count, breaks = breaks, labels = c("1", "2", "3", "4"), include.lowest = TRUE))


mm <- mm %>%
  mutate(Landskap = case_when(
    grepl("1$|4|5|6|8|9|11", L) ~ "Skog",
    grepl("2|3|7|10$|12$|13$", L) ~ "Jordbruk",
    TRUE ~ NA_character_
  ))

mm <- mm %>%
  mutate(Type = case_when(
    grepl("E", L) ~ "Elv",
    grepl("L", L) ~ "Land",
    TRUE ~ NA_character_
  ))

mm$Combined <- paste(mm$Type, mm$Landskap, sep = ".")



ggplot(mm, aes(x=Combined, y=mm)) +
  geom_violin() +
  facet_wrap(~Type, scales = "free", ncol = 2) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  labs(x = "Combined", y = "mm", title = "Violin Plots for Each Combination")


ggplot(mm, aes(x=mm)) +
  geom_density(fill = "blue", alpha = 0.5) +
  facet_wrap(~Type + Landskap, scales = "fixed", ncol = 2) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  labs(x = "mm", y = "Density", title = "Density Plots for Each Combination")




# Calculate medians for each Landskap and order by magnitude
medians_ordered_landskap <- mm %>%
  group_by(Landskap) %>%
  summarise(Median_mm = median(mm, na.rm = TRUE)) %>%
  arrange(Median_mm)

# Calculate medians for each Type and order by magnitude
medians_ordered_Type <- mm %>%
  group_by(Type) %>%
  summarise(Median_mm = median(mm, na.rm = TRUE)) %>%
  arrange(Median_mm)

# Calculate medians for each combination and order by magnitude
medians_ordered_Blanding <- mm %>%
  group_by(Combined) %>%
  summarise(Median_mm = median(mm, na.rm = TRUE)) %>%
  arrange(Median_mm)

# Print the result
print(medians_ordered_Blanding)
print(medians_ordered_Type)
print(medians_ordered_landskap)

# Rename the first column of medians_ordered_Combined to "Cat"
medians_ordered_Blanding <- medians_ordered_Blanding %>%
  rename(Cat = 1)

# Rename the first column of medians_ordered_Type to "Cat"
medians_ordered_Type <- medians_ordered_Type %>%
  rename(Cat = 1)

# Rename the first column of medians_ordered_landskap to "Cat"
medians_ordered_landskap <- medians_ordered_landskap %>%
  rename(Cat = 1)

Median_df <- rbind(
  mutate(medians_ordered_Blanding, Source = "Blanding"),
  mutate(medians_ordered_Type, Source = "Type"),
  mutate(medians_ordered_landskap, Source = "Landskap")
)

# Print the combined data frame
print(Median_df)

sources <- unique(Median_df$Source)

# Define colors for each category
colors <- c(
  "Elv.Jordbruk" = "darkblue", # A mix of blue and brown can be represented by a darker shade of blue
  "Land.Skog" = "darkgreen", # Dark green
  "Elv.Skog" = "darkcyan", # A mix of green and blue can be represented by dark cyan
  "Land.Jordbruk" = "green", # A mix of green and brown can be represented by a darker shade of green
  "Elv" = "lightblue", # Dark blue
  "Land" = "brown", # Changed to brown
  "Skog" = "darkgreen", # Green
  "Jordbruk" = "lightyellow", # Changed to light yellow
  "Forest" = "green" # Green
)


for (source in sources) {
  # Subset the data frame for the current source
  df_subset <- Median_df[Median_df$Source == source, ]
  
  # Create a bar plot for the current source with different colors for each category
  plot <- ggplot(df_subset, aes(x=Cat, y=Median_mm, fill=Cat)) +
    geom_bar(stat="identity", position=position_dodge()) +
    scale_fill_manual(values = colors) +
    geom_text(aes(label = round(Median_mm, 2)), vjust = -0.3, size = 4, color = "black") +
    theme_minimal() +
    labs(x="Category", y="Median (mm)", fill="Kategori", title=paste("Median (mm) for kategori", source)) +
    theme(axis.text.x = element_text(angle = 45, hjust = 1))
  
  # Print the plot
  print(plot)
}





df_Elv <- myDatalong[myDatalong$Type == "Elv", ]
df_Land <- myDatalong[myDatalong$Type == "Land", ]

# View resulting dataframes
df_Elv
df_Land

summary_stats_E <- summary_stats_E %>%
  mutate(location = case_when(
    L == "E1" ~ 1,
    L == "E2" ~ 2,
    L == "E3" ~ 3,
    L == "E4" ~ 4,
    L == "E5" ~ 5,
    L == "E6" ~ 6,
    L == "E7" ~ 7,
    L == "E8" ~ 8,
    L == "E9" ~ 9,
    L == "E10" ~ 10,
    L == "E11" ~ 11,
    L == "E12" ~ 12,
    L == "E13" ~ 13
  ))

# View the updated dataframe
summary_stats_E
colnames(summary_stats_E)[6] <- "Sted"
# Merge 'df_Elv' with 'summary_stats_E' based on the 'L' column
df_Elv_with_median <- merge(df_Elv, summary_stats_E[, c("Sted", "median")], by = "Sted", all.x = TRUE)

# View the updated dataframe
df_Elv_with_median
summary_stats_L <- summary_stats_L %>%
  mutate(location = case_when(
    L == "L1" ~ 1,
    L == "L2" ~ 2,
    L == "L3" ~ 3,
    L == "L4" ~ 4,
    L == "L5" ~ 5,
    L == "L6" ~ 6,
    L == "L7" ~ 7,
    L == "L8" ~ 8,
    L == "L9" ~ 9,
    L == "L10" ~ 10,
    L == "L11" ~ 11,
    L == "L12" ~ 12,
    L == "L13" ~ 13
  ))

# View the updated dataframe
summary_stats_L
colnames(summary_stats_L)[6] <- "Sted"
# Merge 'df_Elv' with 'summary_stats_E' based on the 'L' column
df_Land_with_median <- merge(df_Land, summary_stats_L[, c("Sted", "median")], by = "Sted", all.x = TRUE)

# View the updated dataframe
df_Land_with_median

# Find common column names between the two dataframes
common_col_names <- intersect(names(df_Elv_with_median), names(df_Land_with_median))

# Merge the dataframes based on the common column names
merged_df <- merge(df_Elv_with_median, df_Land_with_median, by = common_col_names, all = TRUE)

# View the merged dataframe
merged_df

# Calculate the median of 'mm' for each unique value in 'L'
median_mm_by_L <- mm %>%
  group_by(L) %>%
  summarise(median_mm = median(mm, na.rm = TRUE))

# Print the result
print(median_mm_by_L)
write.csv(median_mm_by_L, "C:/Users/Fredr/OneDrive - USN/Master oppgave/Master R-stats/median_size.csv", row.names=FALSE)

avg_mm_by_L <- mm %>%
  group_by(L) %>%
  summarise(avg_mm = mean(mm, na.rm = TRUE))
print(avg_mm_by_L)
